# Enchant

This package makes it easier to integrate with Enchant.com

## Usage

To generate Enchant Messenger embed codes:

```python
from enchant import messenger
messenger.embed_code("abc")
```

## Planned

* API helpers to simplify using Enchant's REST API
